package ru.myitschool.work.data.source

import android.content.Context
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import androidx.datastore.preferences.preferencesDataStore
import dagger.hilt.android.qualifiers.ApplicationContext
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map
import javax.inject.Inject
import javax.inject.Singleton

@Singleton
class AuthorizationStorageDataSource @Inject constructor(
    @ApplicationContext private val context: Context,
) {
    private val Context.storage: DataStore<Preferences> by preferencesDataStore(name = NAME)
    val basicAuthToken: Flow<String?> = context.storage.data.map { preferences ->
        preferences[TOKEN_KEY]
    }

    suspend fun updateBasicAuth(token: String?) {
        context.storage.edit { settings ->
            if (token != null) {
                settings[TOKEN_KEY] = "Basic $token"
            } else {
                settings.remove(TOKEN_KEY)
            }
        }
    }

    private companion object {
        const val NAME = "auth_data"
        val TOKEN_KEY = stringPreferencesKey("basicAuthToken")
    }
}